@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
 import logging
 from .sqlparse import SQLAnalyze
+from .sqlparse import SQLFormatWithPrefix
 from .commandanalyze import execute
 from .commandanalyze import CommandNotFound
 from .sqlcliexception import SQLCliException
+import click
+import time
 
 _logger = logging.getLogger(__name__)
 
@@ -11,15 +14,13 @@ _logger = logging.getLogger(__name__)
 class SQLExecute(object):
     conn = None            # 数据库连接
     options = None         # 用户设置的各种选项
+    logfile = None         # 打印的日志文件
+    sqlscript = None       # 需要执行的SQL脚本
 
     def __init__(self):
         # 设置一些默认的参数
-        self.options = {}
-        self.options["WHENEVER_SQLERROR"] = "CONTINUE"
-        self.options["PAGE"] = "OFF"
-        self.options["OUTPUT_FORMAT"] = "ASCII"
-        self.options["ECHO"] = "OFF"
-        self.options["LONG"] = 20
+        self.options = {"WHENEVER_SQLERROR": "CONTINUE", "PAGE": "OFF", "OUTPUT_FORMAT": "ASCII", "ECHO": "OFF",
+                        "LONG": 20, 'KAFKA_SERVERS': None, 'TIMING': 'OFF'}
 
     def set_connection(self, p_conn):
         self.conn = p_conn
@@ -43,9 +44,12 @@ class SQLExecute(object):
             m_CommentSQL = ret_SQLSplitResultsWithComments[m_nPos]
 
             # SQL的回显
-            if self.options["ECHO"] == 'ON':
-                if len(m_CommentSQL.strip()) != 0:
-                    yield 'SQL> ' + m_CommentSQL, None, None, None
+            if self.options["ECHO"] == 'ON' and len(m_CommentSQL.strip()) != 0 and  self.logfile is not None:
+                click.echo(SQLFormatWithPrefix(m_CommentSQL), file = self.logfile)
+
+            # 如果运行在脚本模式下，需要在控制台回显SQL
+            if self.sqlscript is not None:
+                click.secho(SQLFormatWithPrefix(m_CommentSQL))
 
             # 如果是空语句，不在执行
             if len(sql.strip()) == 0:
@@ -69,7 +73,7 @@ class SQLExecute(object):
                 or sql.startswith("set")
             ):
                 if self.options["WHENEVER_SQLERROR"] == "CONTINUE":
-                    yield None,None,None, "Not connected. "
+                    yield None, None, None, "Not connected. "
                 else:
                     raise SQLCliException("Not Connected. ")
             cur = self.conn.cursor() if self.conn else None
@@ -82,8 +86,15 @@ class SQLExecute(object):
                 # 执行正常的SQL语句
                 if cur is not None:
                     try:
+                        start = time.clock()
                         cur.execute(sql)
                         yield self.get_result(cur)
+                        end = time.clock()
+
+                        # 如果需要，打印语句执行时间
+                        if self.options['TIMING'] == 'ON':
+                            yield None, None, None, 'Running time: %10.2f Seconds' % (end - start)
+
                     except Exception as e:
                         if (
                                 str(e).find("SQLSyntaxErrorException") != -1 or
@@ -98,7 +109,7 @@ class SQLExecute(object):
                             raise e
             except SQLCliException as e:
                 if self.options["WHENEVER_SQLERROR"] == "CONTINUE":
-                    yield None,None,None, str(e.message)
+                    yield None, None, None, str(e.message)
                 else:
                     raise e
 
